==> comedi-0.4.4.tgz: comedi-0.4.4/demo/inp.c <==
#include <stdio.h>
#include <comedilib.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <errno.h>

void help(void)
{
	fprintf(stderr,"inp [-r input range] [-f /dev/comediN] <channel number>\n");
	exit(0);
}


void main(int argc,char *argv[])
{
	int data,chan;
	int it;
	char *fn=NULL;
	int i,n=0;
	int ir=-1;
	int aref=-1;
	int err;
	comedi_voltage_info vinfo;

	for(i=1;i<argc;i++){
		if(!strcmp(argv[i],"-f")){
			i++;
			if(i<argc){
				fn=argv[i];
				continue;
			}else help();
		}
		if(!strcmp(argv[i],"-r")){
			i++;
			if(i<argc){
				if(sscanf(argv[i],"%d",&ir))
					continue;
			}
			help();
		}
		if(!strcmp(argv[i],"-d")){
			aref=COMEDI_AREF_DIFF;
			continue;
		}
		if(n==0){
			if(!sscanf(argv[i],"%d",&chan))help();
			n=1;
			continue;
		}
		if(n==1)help();
	}
	if(!fn)fn="/dev/comedi0";

	it=open(fn,O_RDWR);
	if(!it){
		fprintf(stderr,"cannot open %s\n",fn);
		exit(0);
	}

	if(ir>=0){
		if(comedi_setparam(it,chan,COMEDI_RANGE,ir)<0){
			fprintf(stderr,"error changing range to %d\n",ir);
			exit(0);
		}
	}else{
		i=comedi_getparam(it,chan,COMEDI_RANGE,&i,&ir);
		if(i<0)ir=0;
	}
	if(aref>=0){
		if(comedi_setparam(it,chan,COMEDI_AREF,aref)<0){
			fprintf(stderr,"error changing reference to %d\n",
				aref);
			exit(0);
		}
	}
	i=comedi_voltage_range(it,chan,ir,&vinfo);
	
	if(err=comedi_get(it,chan,&data)<0){
		switch(err){
		case -ETIME:
			fprintf(stderr,"timeout\n");
			break;
		default:
			fprintf(stderr,"error triggering device\n");
		}
		exit(0);
	}
	
	printf("%d %g\n",data,vinfo.offset+vinfo.delta*data);
}

==> comedi-0.4.5.tgz: comedi-0.4.5/demo/inp.c <==
#include <stdio.h>
#include <comedilib.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <errno.h>

void help(void)
{
	fprintf(stderr,"inp [-r input range] [-f /dev/comediN] <channel number>\n");
	exit(0);
}


void main(int argc,char *argv[])
{
	int data,chan;
	int it;
	char *fn=NULL;
	int i,n=0;
	int ir=-1;
	int aref=-1;
	int err;
	comedi_voltage_info vinfo;

	for(i=1;i<argc;i++){
		if(!strcmp(argv[i],"-f")){
			i++;
			if(i<argc){
				fn=argv[i];
				continue;
			}else help();
		}
		if(!strcmp(argv[i],"-r")){
			i++;
			if(i<argc){
				if(sscanf(argv[i],"%d",&ir))
					continue;
			}
			help();
		}
		if(!strcmp(argv[i],"-d")){
			aref=COMEDI_AREF_DIFF;
			continue;
		}
		if(n==0){
			if(!sscanf(argv[i],"%d",&chan))help();
			n=1;
			continue;
		}
		if(n==1)help();
	}
	if(!fn)fn="/dev/comedi0";

	it=open(fn,O_RDWR);
	if(!it){
		fprintf(stderr,"cannot open %s\n",fn);
		exit(0);
	}

	if(ir>=0){
		if(comedi_setparam(it,chan,COMEDI_RANGE,ir)<0){
			fprintf(stderr,"error changing range to %d\n",ir);
			exit(0);
		}
	}else{
		i=comedi_getparam(it,chan,COMEDI_RANGE,&i,&ir);
		if(i<0)ir=0;
	}
	if(aref>=0){
		if(comedi_setparam(it,chan,COMEDI_AREF,aref)<0){
			fprintf(stderr,"error changing reference to %d\n",
				aref);
			exit(0);
		}
	}
	i=comedi_voltage_range(it,chan,ir,&vinfo);
	
	if(comedi_get(it,chan,&data)<0){
		switch(errno){
		case -ETIME:
			fprintf(stderr,"timeout\n");
			break;
		default:
			fprintf(stderr,"error triggering device\n");
		}
		exit(0);
	}
	
	printf("%d %g\n",data,vinfo.offset+vinfo.delta*data);
}
